@@ -36,3 +36,15 @@ pub trait Pin: super::IOMUX {
 pub fn prepare<P: Pin>(pin: &mut P) {
     super::alternate(pin, P::ALT);
 }
+
+#[allow(unused)] // Used in chip-specific modules...
+macro_rules! pwm {
+    (module: $module:ty, submodule: $submodule:ty, alt: $alt:expr, pad: $pad:ty, output: $output:ty) => {
+        impl Pin for $pad {
+            const ALT: u32 = $alt;
+            type Output = $output;
+            type Module = $module;
+            type Submodule = $submodule;
+        }
+    };
+}
